---
title: 상점아이디 추가
category: 포트원 이용절차 (온보딩 가이드) > 추가 계약 > 서비스 추가
seo:
  title: 서비스 추가시 상점아이디 추가 계약 안내
  description: >-
    결제대행사와 계약을 맺기 전 미리 연동테스트가 가능한 상점아이디 추가에 대한 안내입니다. 유용하게 제공되는 결제대행사별 서비스 추가
    정보까지 확인해보세요.
  keywords:
    - PG 이용절차
    - 상점아이디
tags:
  - 공통
  - 상점아이디 추가
pgCompanies:
  - 공통
searchTags:
  - 상점추가
  - 상점아이디추가
  - 연동방식추가
  - 서비스추가
  - MID추가
---

![](</uploads/포트원-이용절차/추가-계약/Frame 427320149.png>)

### **상점아이디 추가가 필요한 경우**

<Callout content="상점아이디 추가는 결제 연동을 위한 채널 연동 정보를 하나 더 발급받는 절차를 의미합니다.
아래 내용은 상점아이디 추가에 필요한 일반적인 경우의 수를 나열하였으며, 결제대행사별로 상점아이디 추가 절차 확인을 원하시는 경우 아래 가이드를 상세히 참고해주시기 바랍니다." />

#### 1. 포트원을 통하지 않고 <Highlight text="이미 결제대행사(PG사)와 계약이 되어있는 경우" />

- 포트원 사용 전, 이미 결제대행사와 계약되어있으신 경우라면 포트원용 상점아이디를 추가하신 후 서비스 사용이 가능합니다.
- 포트원의 정책상 기존에 발급된 상점아이디는 그대로 사용이 불가하며 포트원 호스팅으로 등록된 상점아이디만 사용하실 수 있습니다.

#### 2. <Highlight text="새로운 서비스가 추가" /> **되는 경우**

- 새로운 판매상품/업종의 서비스가 추가되거나 사이트 URL(혹은 앱)이 새롭게 런칭되는 경우, 기존의 서비스와 분리가 필요하시다면 새로운 상점아이디를 추가로 발급받으실 수 있습니다.
- 기존에 심사받은 서비스와 다른 서비스(다른 업종,품목 등)라면 추가 심사가 필요하므로 상점아이디는 반드시 추가발급 받으셔야 합니다.

#### 3. <Highlight text="새로운 방식으로 연동" /> **하고자 할 경우**

- 기존에 사용하시던 서비스와 다른 방식으로 연동하실 경우 상점아이디를 구분해야합니다.\
  예를 들어 일반 단건 결제를 이용하시다가 정기결제 서비스를 추가하시는 경우, 정기결제에 대한 심사가 추가로 진행되며 상점아이디로 새롭게 발급됩니다.

### **결제대행사별 서비스 추가 방법**

서비스 추가 방법은 이용하시는 결제대행사별로 상이합니다.

#### **1.** <Highlight text="결제대행사 상점관리자페이지" /> **에서 신청**

상점아이디 추가신청이 결제대행사의 상점관리자 페이지 안에서 이루어지는 경우입니다.

결제대행사에서 제공하는 상점관리자페이지 안에서 상점아이디 추가 신청을 접수해주시기 바랍니다.

이에 해당되는 결제대행사는 **KG이니시스** 입니다.

#### 2. <Highlight text="신규 가입신청 절차와 동일하게" />**로 재접수**

상점아아디 추가 신청절차와 신규 가입신청 절차가 동일한 경우입니다.

포트원 관리자콘솔 > 전자결제신청 을 통해 한번 더 전자결제 신청을 접수해주시기 바랍니다.

이에 해당되는 결제대행사는 **토스페이먼츠, 네이버페이, 카카오페이, NHN KCP** 입니다.

<Callout content="이 때, 포트원 관리자콘솔> 상점 · 계정관리 내에 적혀진 서비스URL 정보가 추가하시려는 URL이 맞는지 확인해주세요. 서비스 추가가 필요한 URL로 적혀있어야 하며, 해당 란에 수정이 필요하실 경우 우측 하단의 채널톡을 통해 포트원 고객지원팀으로 문의주시기 바랍니다." title="유의사항" icon="❗" />

#### 3. <Highlight text="포트원 고객지원팀으로 별도 요청" />

포트원으로 별도 요청하여 상점아이디 추가하는 경우입니다.

포트원 고객지원팀을 통해 아래 정보를 전달주시면 포트원에서 해당 결제대행사로 상점아이디 추가 신청을 접수해드립니다. 접수 이후에는 결제대행사 측에서 담당자님 메일로 직접 안내를 드리고 있으니 참고부탁드립니다.

**1번, 2번의 경우를 제외한 모든 결제대행사**은 3번의 방법으로 신청해주시기 바랍니다.

<Indent level="1">

**공통 필요정보**

- 상호명 :
- 사업자번호 :
- 추가하시려는 서비스 URL :
- 추가하시려는 결제수단 :
- 담당자님 정보 : 성함/연락처/메일주소

</Indent>

<Indent level="1">

**(추가 기재사항) 포트원을 처음 이용하시는 경우**

- 기존에 이용했던 결제대행사 수수료 : 영중소 구분 필수기재
- 기존에 발생되었던 최근 3개월간 평균 매출금액 : 서비스 준비중(구축중)인 경우 '없음'으로 기재

</Indent>

<Callout content="" title="결제대행사별 상점아이디 추가 절차 보러가기↗︎" />
